from mtpiclick.point import point

bottom = 725
left = 108
top = 41
submenu = 307
subsubmenu = 510

product = point(left, top)
home = point(141, bottom)
login = point(865, top)
menu = point(225, bottom)
start = point(52, bottom)
messages = point(512, bottom)
login_password = point(622, 323)
key_3 = point(244, 347)
key_ok = point(927, 466)
login_ok = point(389, 424)
capture = point(807,864)
frame = point(760, 0)


from mtpiclick.click import moveClick
from mtpiclick.point import point
from .hmi import Login, Login_Password, Keyboard_3, Keyboard_OK, Login_OK, Menu
from .coordinates import left, submenu, subsubmenu

supervisor_information = point(left, 281)
supervisor_setup = point(left, 506)
supervisor_system = point(submenu, 382)
supervisor_motor = point(subsubmenu, 318)

def LoginSupervisor():
    Login()
    Login_Password()
    Keyboard_3()
    Keyboard_OK()
    Login_OK()

def InformationSupervisor():
    Menu()
    moveClick(supervisor_information)

def SetupSupervisor(loginFirst=False):
    if (loginFirst):
        LoginSupervisor()
    Menu()
    moveClick(supervisor_setup)

def SystemSupervisor(loginFirst=False):
    SetupSupervisor(loginFirst=loginFirst)
    moveClick(supervisor_system)

def MotorSupervisor(loginFirst=False):
    SystemSupervisor(loginFirst=loginFirst)
    moveClick(supervisor_motor)


import time
import pyautogui

def moveClick(target):
    """

    Parameters
    ----------
    target :
        

    Returns
    -------

    """
    pyautogui.moveTo(target.x, target.y, 1, tween=pyautogui.easeInOutQuad)
    pyautogui.moveTo(target.x, target.y, 1)
    time.sleep(0.1)
    pyautogui.mouseDown()
    time.sleep(0.1)
    pyautogui.mouseUp()
    time.sleep(1)


import time
import pyautogui as gui
from .coordinates import home, login, login_password, key_3, key_ok, login_ok, menu, capture, frame
from mtpiclick.click import moveClick

def MoveHome():
    gui.moveTo(home.x, home.y, 1)

def Home():
    moveClick(home)

def Login():
    moveClick(login)

def Login_Password():
    moveClick(login_password)

def Keyboard_3():
    moveClick(key_3)

def Keyboard_OK():
    moveClick(key_ok)

def Login_OK():
    moveClick(login_ok)

def Menu():
    moveClick(menu)

def RecordStart():
    moveClick(capture)
    time.sleep(2.5)
    moveClick(frame)
    Home()
    gui.keyDown('shift')
    gui.press('f9')
    gui.keyUp('shift')
    time.sleep(5)

def RecordStop():
    Home()
    time.sleep(2)
    gui.keyDown('shift')
    gui.press('f9')
    gui.keyUp('shift')

def Record(navigation):
    RecordStart()
    navigation()
    RecordStop()


from setuptools import setup, find_packages
setup(
    author="Patrick Toohey",
    description="HMI automation tools.",
    name="mtpiclick",
    version="0.0.5",
    packages=find_packages(include=["mtpiclick","mtpiclick.*"]),
    install_requires=['pyautogui'],
    python_requires='>=3.7',
)